{% extends "help/base.html" %}
{% load i18n %}

{% block help_con %}

<h3 class="hd">{% trans "Setting Sync Interval" %}</h3>

<p>{% trans "Usually Seafile client automatically detects changes on local folder and upload the changes to server. However, if the local folder is in a Windows network share drive, Seafile client cannot detect changes reliably. In this case, you can ask Seafile client to periodically checks for changes in the local folder. You can set the interval of this periodic sync. The interval is set in the unit of seconds." %}</p>

<img src="{{MEDIA_URL}}img/help/set-sync-interval.png" width="400" alt="" />

{% endblock %}
