{% extends "help/base.html" %}
{% load i18n %}

{% block help_con %}

<h3 class="hd">{% trans "Selective Sync Sub-folders" %}</h3>

<p>{% trans "You may have some very large libraries on the Seafile server. And you're currently only interested in a sub-folder inside one library. If your Seafile server is Pro edition, you can selectively sync a sub-folder in a library, instead of syncing the entire library." %}</p>

<p>{% blocktrans %}To sync a sub-folder, open cloud file browser by double clicking a library which hasn't been synced. Navigate into the parent folder of that sub-folder. Right click on the sub-folder. Choose "Sync this folder" in the pop-up menu.{% endblocktrans %}</p>

<img src="{{MEDIA_URL}}img/help/sync-a-sub-folder.png" width="550" alt="" />

<p>{% blocktrans %}After syncing the sub-folder, you can see its syncing status in the "Synced Libraries" group in the client's main window.{% endblocktrans %}</p>

{% endblock %}
