{% extends "base2.html" %}

{% block js %}{% spaceless %}
    {{ block.super }}
    <script type="text/javascript">
        alert("this alert shouldn't be alone!");
    </script>
{% endspaceless %}{% endblock %}
