{% extends 'view_file_base.html' %}

{% block extra_style %}{{block.super}}
{% if not err%}
<link rel="stylesheet" href="{{MEDIA_URL}}css/mediaelementplayer.css" />
{% endif %}
{% endblock %}

{% block extra_script %}{{ block.super }}
{% if not err%}
<script src="{{MEDIA_URL}}js/mediaelement-and-player.min.js"></script>
<script type="text/javascript">
  $('#file-view').html('<div class="audio-container"><audio src="{{raw_path}}" width="500" height="30"></audio></div>');
$('audio').mediaelementplayer(/* Options */);
</script>
{% endif %}
{% endblock %}

