{% load i18n %}
<script type="text/template" id="dir-view-tmpl">
    <div class="repo-file-list-topbar">
        <p class="path-bar"></p>
        <div class="repo-op"></div>
    </div>
    <div class="js-dir-content">
        <table class="repo-file-list">
            <thead></thead>
            <tbody></tbody>
        </table>
        <ul class="grid-view hide">
        </ul>
    </div>
    <span class="loading-icon loading-tip"></span>
    <p class="error hide"></p>
</script>
