#!/usr/bin/env python
# encoding: utf-8

TRANSLATION_MAP = {
    'Added' : u'添加了',
    'Deleted' : u'删除了',
    'Removed' : u'删除了',
    'Modified' : u'修改了',
    'Renamed' : u'重命名或移动了',
    'Moved' : u'移动了',
    'Added directory' : u'新建了目录',
    'Removed directory' : u'删除了目录',
    'Renamed directory' : u'重命名了目录',
    'Moved directory' : u'移动了目录',
}
