{% extends 'view_file_base.html' %}
{% load i18n%}
{% load staticfiles %}

{% block extra_style %}{{ block.super }}
{% if not err %}
    {% include 'snippets/office_convert_style.html' %}
    <link rel="stylesheet" type="text/css" media="print" href="{{ MEDIA_URL }}css/print_for_file_view.css" />
{% endif %}
{% endblock %}

{% block file_view %}
{% if not err %}
    {% include 'snippets/office_convert_html.html' %}
{% endif %}
{% endblock %}

{% block extra_script %}{{ block.super }}
{% if not err %}
<script type="text/javascript">
    {% include 'snippets/office_convert_js.html' %}
</script>
{% endif %}
{% endblock %}
