{% extends 'view_file_base.html' %}
{% load i18n %}

{% block extra_script %}{{ block.super }}
<script type="text/javascript">
$('#file-view').html('<div id="file-view-tip"></div>');
</script>
{% endblock %}
