{% load seahub_tags i18n %}
<div class="item">
    <p>{% trans "Used:" %} {{ space_usage|seahub_filesizeformat }} {% if space_quota > 0 %}/ {{ space_quota|seahub_filesizeformat }} {% endif %}</p>

    {% if space_quota > 0 %}
    <div id="quota-bar">
        <a href="http://www.seafile.com/{% if LANGUAGE_CODE != 'zh-cn' %}en/{% endif %}help/quota/" target="_blank">
            <span id="quota-usage" class="usage" style="width:{{rates.space_usage}};"></span>
        </a>
    </div>
    {% endif %}

    {% if user.trialing %}
    <p><a href="{{user.trial_info.payment_url}}">Trial expires at {{user.trial_info.expire_date|date:"Y-m-d"}}</a></p>
    {% endif %}
</div>

{% if SHOW_TRAFFIC and TRAFFIC_STATS_ENABLED %}
<div class="item" id="traffic-stat">{% trans "Traffic this month:" %} {{ traffic_stat|filesizeformat }}</div>
{% endif %}

{% if ENABLE_PAYMENT %}
<a class="item" href="{{ payment_url }}">{% trans "Payment" %}</a>
{% endif %}
