        {% if fileext == 'c' %}
        mode: 'text/x-csrc',
        {% endif %}
        {% if fileext == 'cpp' or fileext == 'cc' %}
        mode: 'text/x-c++src',
        {% endif %}
        {% if fileext == 'cs' %}
        mode: 'text/x-csharp',
        {% endif %}
        {% if fileext == 'java' %}
        mode: 'text/x-java',
        {% endif %}
        {% if fileext == 'css' %}
        mode: 'css',
        {% endif %}
        {% if fileext == 'html' or fileext == 'xhtml' or fileext == 'htm' %}
        mode: 'htmlmixed',
        {% endif %}
        {% if fileext == 'js' %}
        mode: 'javascript',
        {% endif %}
        {% if fileext == 'pl' %}
        mode: 'perl',
        {% endif %}
        {% if fileext == 'php' %}
        mode: 'php',
        {% endif %}
        {% if fileext == 'py' %}
        mode: 'python',
        {% endif %}
        {% if fileext == 'rb' %}
        mode: 'ruby',
        {% endif %}
        {% if fileext == 'sh' %}
        mode: 'shell',
        {% endif %}
        {% if fileext == 'txt' or fileext == 'text' %}
        mode: null,
        {% endif %}
        {% if fileext == 'xml' %}
        mode: 'xml',
        {% endif %}
