{% extends "base.html" %}

{% block nav_feedback_class %}class="cur"{% endblock %}

{% block right_panel %}
<script type="text/javascript" src="http://open.denglu.cc/connect/commentcode?appid=59289denyu9jLcO03et5bMAo73jwAA"></script>
{% endblock %}

{% block extra_script %}
{% endblock %}
