{% load i18n %}
<a href="{{SITE_ROOT}}help/" target="_blank">{% trans "Help" %}</a>
<a href="#" class="js-about">{% trans "About" %}</a>
<a href="{% url 'download_client' %}" class="fright"><span aria-hidden="true" class="sf2-icon-monitor vam"></span> <span class="vam">{% trans "Clients" %}</span></a>

<div class="about-content hide">
    <p><img src="{{ MEDIA_URL }}{{ logo_path }}" title="{{ site_title }}" alt="logo" width="{{logo_width}}" height="{{logo_height}}" /></p>
    <p>{% trans "Server Version: " %}{{ seafile_version }}<br/> © 2017 {% trans "Seafile" %}</p>
    <p><a href="{% if LANGUAGE_CODE == 'zh-cn' %}http://seafile.com/about/{% else %}http://seafile.com/en/about/{% endif %}" target="_blank">{% trans "About Us" %}</a></p>
</div>
