{% extends "rest_framework/base.html" %}

{# Override this template in your own templates directory to customize #}
{% block title %}Seafile RESTful API {% endblock %}

{% block branding %}<a href='http://seafile.com'>Seafile</a>{% endblock %}
