{% extends 'view_history_file.html' %}
{% load i18n %}
{% load url from future %}

{% block file_path %}
<p class="file-view-meta-info">{% trans "Current Path: "%}{% trans "Trash" %}</p>
{% endblock %}
