{% extends 'email_base.html' %}

{% load i18n seahub_tags %}

{% block email_con %}
{% autoescape off %}

<p style="color:#121214;font-size:14px;">{% trans "Hi," %}</p>

<p style="font-size:14px;color:#434144;">
{% blocktrans with escaped_nickname=email|email2nickname|escape %}{{ escaped_nickname }} shared an upload link to you on {{ site_name }}.{% endblocktrans%}
</p>

<p style="font-size:14px;color:#434144;">
{% trans "You can go to the following page and upload your files:" %}<br />
<a href="{{ shared_upload_link }}">{{ shared_upload_link }}</a>
</p>

{% if extra_msg %}
<p>" {{ extra_msg }} "</p>
{% endif %}

{% endautoescape %}
{% endblock %}
