{% extends 'email_base.html' %}

{% load i18n %}

{% block email_con %}

{% autoescape off %}

<p style="color:#121214;font-size:14px;">{% trans "Hi," %}</p>

<p style="font-size:14px;color:#434144;">
{% blocktrans with account=user.username %}To reset the password of your account {{ account }} on {{ site_name }}, please click the following link: {% endblocktrans %}
</p>

<p>
<a href="{{ url_base }}{% url 'auth_password_reset_confirm' uidb36=uid token=token %}">{{ url_base }}{% url 'auth_password_reset_confirm' uidb36=uid token=token %}</a>
</p>

<p style="font-size:14px;color:#434144;">
{% trans "If you did not request it, just skip it." %}
</p>

{% endautoescape %}

{% endblock %}
