# Getting the normal admin routines, classes, and `site` instance.
from django.contrib.admin import (
    autodiscover, site, AdminSite, ModelAdmin, StackedInline, TabularInline,
    HORIZONTAL, VERTICAL,
)
# Geographic admin options classes and widgets.
from django.contrib.gis.admin.options import GeoModelAdmin, OSMGeoAdmin
from django.contrib.gis.admin.widgets import OpenLayersWidget

__all__ = [
    'autodiscover', 'site', 'AdminSite', 'ModelAdmin', 'StackedInline',
    'TabularInline', 'HORIZONTAL', 'VERTICAL', 'GeoModelAdmin', 'OSMGeoAdmin',
    'OpenLayersWidget',
]
