{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Successfully reset password" %}{% endblock %}

{% block main_content %}
<div class="text-panel">
    <p>{% trans "Successfully reset password." %} <a href="{{ login_url }}">{% trans "Log In" %}</a></p>
</div>
{% endblock %}
