{% extends "base.html" %}
{% load i18n %}

{% block sub_title %}{% trans "Download" %} - {% endblock %}

{% block main_panel %}
<div class="article">
    {% if LANGUAGE_CODE == 'zh-cn' %}
    <p>你可以从 Seafile 的<a href="http://seafile.com/download/">官方下载页面</a>下载 Windows，Mac 以及 Linux 的客户端。</p>
    {% else %}
    <p>You can download Seafile desktop client for Windows, Mac and Linux from Seafile's <a href="http://seafile.com/en/download/">official download page</a>.</p>
    {% endif %}
</div>
{% endblock %}

