.page-container {
    width: 850px;
    border: 1px solid #ccc;
    box-shadow: 0 0 6px #ccc;
    margin: 13px auto;
}
.page-container iframe {
    width: 100%;
    height: 100%;
    border:0;
}
.pdf2html-toolbar {
    position:fixed;
    left:50%;
    bottom:0;
    padding:20px 50px 0;
}
.pdf2html-toolbar .inner {
    padding:2px 5px;
    background: #000;
    opacity:0.75;
    border-radius:3px;
    -ms-user-select:none;
    -moz-user-select:none;
    -webkit-user-select:none;
    user-select:none;
}
.pdf2html-toolbar span {
    font-size:1.5em;
    color:#fff;
    cursor:pointer;
    margin: 0 0.3em;
}
