{% if filetype == 'Text' %}
<script type="text/javascript" src="{{MEDIA_URL}}codemirror/codemirror-2.36.js"></script>
{% endif %}
{% if filetype == 'PDF' and use_pdfjs %}
<script type="text/javascript" src="{{MEDIA_URL}}js/pdf.js"></script>
{% endif %}
{% if filetype == 'Audio' %}
<script src="{{MEDIA_URL}}js/mediaelement-and-player.min.js"></script>
{% endif %}
{% if filetype == 'Video' %}
<script src="{{MEDIA_URL}}js/video.min.js"></script>
{% endif %}
{% if filetype == 'Markdown' %}
<script type="text/javascript" src="{{MEDIA_URL}}js/editormd/lib/marked.min.js"></script>
{% endif %}
