{% extends 'base.html' %}

{% load seahub_tags avatar_tags group_avatar_tags i18n %}

{% block sub_title %}{{group.group_name}} - {% endblock %}

{% block main_content %}
<div class="row">
    <div class="side-tabnav side-nav col-md-3">
        <a href="#" title="{% trans "Close" %}" aria-label="{% trans "Close" %}" class="sf2-icon-x1 sf-popover-close op-icon hidden-md-up js-close-side-nav fright"></a>
    {% block left_panel %}
        <div class="hd w100 ovhd">
            <h3>
                {% grp_avatar group.props.id 32 %} <a title="{{ group.group_name }}" class="grp-name ellipsis vam" href="{% url 'group_info' group.id %}">{{ group.group_name }}</a>
            </h3>
        </div>
    {% endblock %}
    </div>

    <div id="right-panel" class="col-md-9 col-md-offset-3">
    {% block right_panel %}{% endblock %}
    </div>
</div>

{% endblock %}
